#
# spec file for package srt
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1

Name:           srt
Version:        1.3.4
Release:        1.45
Summary:        Secure Reliable Transport (SRT)
License:        MPL-2.0
Group:          Development/Libraries/C and C++
URL:            https://www.srtalliance.org
Source0:        https://github.com/Haivision/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
Patch0:         CVE-2019-15784.patch

BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  tcl
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)

%description
SRT is a video transport protocol and technology stack
that optimizes streaming performance across unpredictable networks
with secure streams and firewall traversal.

%package -n libsrt%{sover}
Summary:        Secure Reliable Transport (SRT) library
Group:          System/Libraries

%description -n libsrt%{sover}
This package contains a shared system library for Secure Reliable
Transport (SRT).

%package devel
Summary:        Development files for the Secure Reliable Transport (SRT) library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libsrt%{sover} = %{version}

%description devel
This package contains all necessary include files and libraries
needed to develop applications with Secure Reliable Transport
(SRT) support.

%prep
%autosetup -p1

%build
%cmake \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	-DCMAKE_INSTALL_BINDIR=%{_bindir} \
	-DCMAKE_INSTALL_LIBDIR=%{_libdir} \
	-DCMAKE_INSTALL_INCLUDEDIR=%{_includedir} \
	-DENABLE_CXX11=ON \
	-DENABLE_SHARED=ON \
	-DENABLE_STATIC=OFF \
	%{nil}
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}/%{_prefix}

%post -n libsrt%{sover} -p /sbin/ldconfig
%postun -n libsrt%{sover} -p /sbin/ldconfig

%files
%doc CONTRIBUTING.md README.md
%{_bindir}/%{name}-ffplay
%{_bindir}/%{name}-file-transmit
%{_bindir}/%{name}-live-transmit
%{_bindir}/%{name}-tunnel

%files -n libsrt%{sover}
%license LICENSE
%{_libdir}/libsrt.so.*

%files devel
%{_includedir}/%{name}/
%{_libdir}/libsrt.so
%{_libdir}/pkgconfig/haisrt.pc
%{_libdir}/pkgconfig/srt.pc

%changelog
* Fri Aug 30 2019 atoptsoglou@suse.com
- Backported commit 47e5890 and 64875fa to fix CVE-2019-15784
  (boo#1148844) and avoid a potential array overflow.
  * Added CVE-2019-15784.patch
* Thu Aug 29 2019 atoptsoglou@suse.com
- Update to version 1.3.4:
  + Various bugfixes and feature enhancments.
* Mon Aug 19 2019 bjorn.lie@gmail.com
- Update to version 1.3.3:
  + Various bugfixes and feature enhancments.
- Update to version 1.3.2:
  + Various bugfixes, feature enhancments, build fixes and
    documentation updates.
- Drop srt-no-rpath.patch: Fixed upstream.
* Tue Nov 13 2018 alarrosa@suse.com
- Fix install prefix in cmake so the pkgconfig file has correct
  information on where to find srt's libraries and include files.
* Mon Oct 29 2018 dimstar@opensuse.org
- Add pkgconfig(zlib) BuildRequires: until openssl 1.1.1, zlib was
  pulled in into our buildroot, avoiding srt having to care for it
  explicitly. Since this is changed now, we have to worry for our
  dependency on our own. The dep comes from:
  CMakeLists.txt:set (SSL_REQUIRED_MODULES "openssl libcrypto zlib")
* Wed Aug  8 2018 jengelh@inai.de
- Trim marketing from description.
* Fri Jul 13 2018 bjorn.lie@gmail.com
- Update to version 1.3.1:
  + Various bugfixes.
* Thu Jul 12 2018 jengelh@inai.de
- Update summaries.
* Fri Jun 29 2018 bjorn.lie@gmail.com
- Add baselibs.conf: build 32bit support libs.
* Thu May 31 2018 bjorn.lie@gmail.com
- Update Summary and Descriptions fields.
* Mon May 21 2018 bjorn.lie@gmail.com
- Inital packaging.
